Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Printer ¶
type Printer struct {
// Total number of bytes written
Written int64
// contains filtered or unexported fields
}
func NewPrinter ¶
NewPrinter returns a writer nexus. The referenced error is set by all methods if an error occurs.
func (*Printer) Print ¶
func (t *Printer) Print(args ...interface{})
Print prints arguments using the underlying writer. Does nothing if Printer has failed.
func (*Printer) Printf ¶
Printf prints a formated string using the underlying writer. Does nothing if Printer has failed.
Click to show internal directories.
Click to hide internal directories.